@@ -10,7 +10,7 @@ use Net::Stomp;
 use vars qw($VERSION);
 use strict;
 
-$VERSION = '0.1.3';
+$VERSION = '0.1.4';
 
 use Carp qw(croak);
 use Data::Dumper;
@@ -516,13 +516,46 @@ POE::Component::MessageQueue - A POE message queue that uses STOMP for the commu
     storage => POE::Component::MessageQueue::Storage::Complex->new({
       data_dir     => $DATA_DIR,
       timeout      => 2,
-	  throttle_max => 2
+      throttle_max => 2
     })
   });
 
   POE::Kernel->run();
   exit;
 
+=head1 COMMAND LINE
+
+If you are only interested in running with the recommended storage backend and
+some predetermined defaults, you can use the included command line script.
+
+  user$ mq.pl --usage
+  POE::Component::MessageQueue version 0.1.4
+  Copyright 2007 David Snopek
+  
+  mq.pl [--port|-p <num>] [--hostname|-h <host>]
+        [--timeout|-i <seconds>]   [--throttle|-T <count>]
+        [--data-dir <path_to_dir>] [--log-cont <path_to_file>]
+        [--background|-b] [--pidfile|-p <path_to_file>]
+        [--version|-v] [--help|-h]
+  
+  SERVER OPTIONS:
+    --port     -p <num>    The port number to listen on (Default: 61613)
+    --hostname -h <host>   The hostname of the interface to listen on (Default: localhost)
+  
+  STORAGE OPTIONS:
+    --timeout  -i <secs>   The number of seconds to keep messages in the front-store (Default: 4)
+    --throttle -T <count>  The number of messages that can be stored at once before throttling (Default: 2)
+    --data-dir <path>      The path to the directory to store data (Default: /var/lib/perl_mq)
+    --log-conf <path>      The path to the log configuration file (Default: /etc/perl_mq/log.conf
+  
+  DAEMON OPTIONS:
+    --background -b        If specified the script will daemonize and run in the background
+    --pidfile    -p <path> The path to a file to store the PID of the process
+  
+  OTHER OPTIONS:
+    --version    -v        Show the current version.
+    --help       -h        Show this usage message
+
 =head1 DESCRIPTION
 
 This module implements a message queue [1] on top of L<POE> that communicates
@@ -588,7 +621,7 @@ L<POE::Component::MessageQueue::Storage::Generic> -- Uses L<POE::Component::Gene
 
 =item *
 
-L<POE::Component::MessageQueue::Storage::Generic::DBI> -- A synchronise L<DBI>-based storage engine that can be used in side of Generic.  This provides the basis for the L<POE::Component::MessageQueue::Storage::DBI> module.
+L<POE::Component::MessageQueue::Storage::Generic::DBI> -- A synchronous L<DBI>-based storage engine that can be used in side of Generic.  This provides the basis for the L<POE::Component::MessageQueue::Storage::DBI> module.
 
 =item *
 
